@@ -22,16 +22,13 @@
 
 #ifndef KIO_OBEXFTP_H
 #define KIO_OBEXFTP_H
+
 #include "kdedobexftp.h"
 
-#include <QtCore/QObject>
-#include <QDBusObjectPath>
-#include <QEventLoop>
+#include <QObject>
 
 #include <kio/slavebase.h>
 
-typedef QMap<QString, QString> DeviceInfo;
-
 class OrgBluezObexFileTransfer1Interface;
 class KioFtp
     : public QObject
@@ -43,48 +40,35 @@ public:
     KioFtp(const QByteArray &pool, const QByteArray &app);
     virtual ~KioFtp();
 
-    virtual void copy(const KUrl &src, const KUrl &dest, int permissions, KIO::JobFlags flags);
-    virtual void listDir(const KUrl &url);
+    virtual void copy(const QUrl &src, const QUrl &dest, int permissions, KIO::JobFlags flags);
+    virtual void listDir(const QUrl &url);
     virtual void setHost(const QString &host, quint16 port, const QString &user, const QString &pass);
-    virtual void stat(const KUrl &url);
-    virtual void del(const KUrl &url, bool isfile);
-    virtual void mkdir(const KUrl&url, int permissions);
-    virtual void rename(const KUrl& src, const KUrl& dest, KIO::JobFlags flags);
-    virtual void get(const KUrl& url);
-
-    bool cancelTransfer(const QString &transfer);
+    virtual void stat(const QUrl &url);
+    virtual void del(const QUrl &url, bool isfile);
+    virtual void mkdir(const QUrl&url, int permissions);
+    virtual void rename(const QUrl& src, const QUrl& dest, KIO::JobFlags flags);
+    virtual void get(const QUrl& url);
 
 private Q_SLOTS:
     void updateProcess();
 
-private:
-    void copyHelper(const KUrl &src, const KUrl &dest);
-    void copyWithinObexftp(const KUrl &src, const KUrl &dest);
-    void copyFromObexftp(const KUrl &src, const KUrl &dest);
-    void copyToObexftp(const KUrl &src, const KUrl &dest);
-    void statHelper(const KUrl &url);
-
-    QList<KIO::UDSEntry> listFolder(const KUrl &url, bool *ok);
-    bool changeFolder(const QString &folder);
-    bool createFolder(const QString &folder);
-    bool copyFile(const QString &src, const QString &dest);
-    bool deleteFile(const QString &file);
-
-    void updateRootEntryIcon(KIO::UDSEntry &entry, const QString &memoryType);
+    KIO::UDSEntry entryFromInfo(const QVariantMap &info);
+    void copyHelper(const QUrl &src, const QUrl &dest);
+    void copyFromObexftp(const QUrl &src, const QUrl &dest);
+    void copyToObexftp(const QUrl &src, const QUrl &dest);
+    void statHelper(const QUrl &url);
     void launchProgressBar();
-    void connectToHost();
-    bool testConnection();
-    bool createSession(const QString &target);
 
 private:
-    int m_counter;
+    int                          m_counter;
+    bool                         m_settingHost;
     QMap<QString, KIO::UDSEntry> m_statMap;
-    QString m_host;
-    QString m_uuids;
-    QString m_sessionPath;
-    QTimer *m_timer;
-    org::kde::ObexFtp *m_kded;
+    QString                      m_address;
+    QString                      m_sessionPath;
+    QTimer                      *m_timer;
+    org::kde::ObexFtp           *m_kded;
     OrgBluezObexFileTransfer1Interface *m_transfer;
+
 };
 
 #endif // KIO_OBEXFTP_H
